#!/usr/bin/perl
# getDeviceContactStatus.pl script 
# retrieves the device list from Data Aggregator with Contact Status information in csv format
#	it creates .xml file and then transforms this to .csv
#	it works with deviceTocsv.xsl
#
# e.g. perl  getDeviceContactStatus.pl IMDA:8581 devices
#
# Prerequisites: tested with perl 5.18
#	typically, REST::Client and XML::XSLT modules must be installed (cpan)
#
# DISCLAIMER
# This script is provided AS IS and no warranties are provided or made.  
# For more information refer to http://www.ca.com/us/legal/terms-for-user-sites.aspx


use strict;
use REST::Client;
use XML::XSLT;

my $num_args = $#ARGV + 1;

if ($num_args < 3) {
	if ($num_args == 2) {
	  push(@ARGV, '0');
	} else {
	  print "\nUsage: getDeviceContactStatus.pl DA_host_and_port (e.g. IMDA:8581) outputfilename (without suffix)\n";
	  exit;
	}
}
my $input=$ARGV[0];
my $filename=$ARGV[1];
my $debug=$ARGV[2];						# debug options: 
my $xslfile="deviceTocsv.xsl";
my $itemid;
my $hostname;
my $ipaddress;  
my $rc;

open(XML,"> " . $filename . ".xml")
	or die "error when creating outputfile '$filename'.xml: $!\n";

my $xmlbody = '<FilterSelect xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:noNamespaceSchemaLocation="filter.xsd">';
$xmlbody = $xmlbody . '<Select use="exclude">';
$xmlbody = $xmlbody . '  <Item use="exclude">';
$xmlbody = $xmlbody . '     <Name use="include"/>';
$xmlbody = $xmlbody . '  </Item>';
$xmlbody = $xmlbody . '  <Device use="exclude">';
$xmlbody = $xmlbody . '     <PrimaryIPAddress use="include"/>';
$xmlbody = $xmlbody . '     <CalculatedContactStatus use="include"/>';
$xmlbody = $xmlbody . '  </Device>';
$xmlbody = $xmlbody . '</Select>';
$xmlbody = $xmlbody . '</FilterSelect>';


my $host = "http://$input";
my $client = REST::Client->new();
$client->setHost($host);
$client->addHeader('Content-Type', 'application/xml');

$client->POST('/rest/devices/filtered', $xmlbody);	
$rc = $client->responseCode();
print XML $client->responseContent();
close(XML);

open(CSV,"> " . $filename . ".csv")
  or die "file open error': $!\n";

my $parser = XML::XSLT->new ($xslfile);
print CSV $parser->serve($filename . ".xml",  xml_declaration=>0, http_headers=>0);
close(CSV);

exit;
